@@ -6,13 +6,17 @@ use warnings::register;
 use 5.006;
 
 # ABSTRACT: An extension of the File::stat module, provides additional methods.
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
-#pod =head1 SYNOPSIS
+#pod =begin :prelude
 #pod
 #pod =for test_synopsis
 #pod my ($st, $file);
 #pod
+#pod =end :prelude
+#pod
+#pod =head1 SYNOPSIS
+#pod
 #pod   use File::stat::Extra;
 #pod
 #pod   $st = lstat($file) or die "No $file: $!";
@@ -519,10 +523,33 @@ File::stat::Extra - An extension of the File::stat module, provides additional m
 
 =head1 VERSION
 
-version 0.007
+version 0.008
+
+=for test_synopsis my ($st, $file);
 
 =head1 SYNOPSIS
 
+  use File::stat::Extra;
+
+  $st = lstat($file) or die "No $file: $!";
+
+  if ($st->isLink) {
+      print "$file is a symbolic link";
+  }
+
+  if (-x $st) {
+      print "$file is executable";
+  }
+
+  use Fcntl 'S_IRUSR';
+  if ( $st->cando(S_IRUSR, 1) ) {
+      print "My effective uid can read $file";
+  }
+
+  if ($st == stat($file)) {
+      printf "%s and $file are the same", $st->file;
+  }
+
 =head1 DESCRIPTION
 
 This module's default exports override the core stat() and lstat()
@@ -725,29 +752,6 @@ Note: the smartmatch C<~~> operator is only overloaded on Perl version
 As the other operators (C<+>, C<->, C<*>, etc.) are meaningless, they
 have not been overloaded and will cause a run-time error.
 
-=for test_synopsis my ($st, $file);
-
-  use File::stat::Extra;
-
-  $st = lstat($file) or die "No $file: $!";
-
-  if ($st->isLink) {
-      print "$file is a symbolic link";
-  }
-
-  if (-x $st) {
-      print "$file is executable";
-  }
-
-  use Fcntl 'S_IRUSR';
-  if ( $st->cando(S_IRUSR, 1) ) {
-      print "My effective uid can read $file";
-  }
-
-  if ($st == stat($file)) {
-      printf "%s and $file are the same", $st->file;
-  }
-
 =head1 WARNINGS
 
 When a file (handle) can not be (l)stat-ed, a warning C<Unable to
@@ -814,7 +818,7 @@ L<stat> and L<lstat> for the original C<stat> and C<lstat> functions.
 
 =head1 AUTHOR
 
-Hayo Baan <hayobaan@cpan.org>
+Hayo Baan <info@hayobaan.com>
 
 =head1 COPYRIGHT AND LICENSE
 
